@@ -36,13 +36,13 @@
 
 // Qt includes
 
-#include <QtCore/QFlags>
-#include <QtCore/QObject>
-#include <QtCore/QVariant>
-#include <QtCore/QList>
-#include <QtCore/QUrl>
-#include <QtCore/QByteArray>
-#include <QtGui/QImage>
+#include <QFlags>
+#include <QObject>
+#include <QVariant>
+#include <QList>
+#include <QUrl>
+#include <QByteArray>
+#include <QImage>
 
 // Local includes
 
@@ -76,8 +76,8 @@ enum Features
     ImagesHasComments              = 1 << 1,  /** This feature specifies that images in the host application has descriptions associated to them.                                   */
     ImagesHasTime                  = 1 << 2,  /** This feature specifies that images has a date associated with it, which the host application can display and set.                 */
     HostSupportsDateRanges         = 1 << 3,  /** This feature specifies whether the host application supports that the user can specify a date range for images, like 1998-2000.   */
-    HostAcceptNewImages            = 1 << 4,  /** This feature specifies that the host application do accept new images. Use \ref ImageCollection::uploadPath to find the
-                                                  location to place the image, and \ref KIPI::Interface::addImage() to tell the host application about the new image.               */
+    HostAcceptNewImages            = 1 << 4,  /** This feature specifies that the host application do accept new images. Use \ref ImageCollection::uploadUrl to find the
+                                                  location to place the image, and \ref Interface::addImage() to tell the host application about the new image.               */
     ImagesHasTitlesWritable        = 1 << 5,  /** This feature specifies whether the plugin can change the title for images.                                                        */
     CollectionsHaveCategory        = 1 << 6,  /** This feature specifies that collections are category associated to them ('travels', 'friends', 'monuments', etc.).                */
     CollectionsHaveCreationDate    = 1 << 7,  /** This feature specifies that collections are a creation date associated to them.                                                   */
@@ -85,7 +85,7 @@ enum Features
     HostSupportsTags               = 1 << 9,  /** This feature specifies whether the host application supports keywords for images.                                                 */
     HostSupportsRating             = 1 << 10, /** This feature specifies whether the host application supports rating values for images.                                            */
     HostSupportsThumbnails         = 1 << 11, /** This feature specifies that host application can provide image thumbnails.                                                        */
-    HostSupportsReadWriteLock      = 1 << 12, /** This feature specifies that host application has mechanism to lock/unlock items to prevent concurent operations.                  */
+    HostSupportsReadWriteLock      = 1 << 12, /** This feature specifies that host application has mechanism to lock/unlock items to prevent concurrent operations.                 */
     HostSupportsPickLabel          = 1 << 13, /** This feature specifies whether the host application supports pick label values for images, used for photograph workflow.          */
     HostSupportsColorLabel         = 1 << 14, /** This feature specifies whether the host application supports color label values for images, used to sort item with color flag.    */
     HostSupportsItemReservation    = 1 << 15, /** This feature specifies whether the host application supports item reservation.                                                    */
@@ -187,7 +187,7 @@ public:
 public:
 
     MetadataProcessor()          {};
-    virtual ~MetadataProcessor() {};
+    ~MetadataProcessor() override {};
 
     virtual bool load(const QUrl& url) = 0;
     virtual bool applyChanges() = 0;
@@ -264,7 +264,7 @@ class LIBKIPI_EXPORT Interface : public QObject
 public:
 
     explicit Interface(QObject* const parent, const QString& name=QString());
-    virtual ~Interface();
+    ~Interface() override;
 
     /**
      * Tells whether the host application under which the plugin currently executes a given feature.
@@ -314,7 +314,7 @@ public:
     virtual void refreshImages(const QList<QUrl>&);
 
     /**
-     * Tells to host application to render imediatly a preview image for one item.
+     * Tells to host application to render immediatly a preview image for one item.
      * This method re-implemented in host application and be thread safe.
      */
     virtual QImage preview(const QUrl& url);
@@ -322,18 +322,18 @@ public:
     /**
      * Tell to host application to save image at url in specific format (JPG, PNG, TIF, etc).
      * Pixels image data must be in ARGB, with image size (width,height).
-     * Pixels can be in siwteen bits per color per pixels and can have an alpha chanel.
+     * Pixels can be in sixteen bits per color per pixels and can have an alpha channel.
      * If cancel flag is passed it permit to cancel save operation.
      * This method re-implemented in host application must be thread safe.
      */
     virtual bool saveImage(const QUrl& url, const QString& format,
                            const QByteArray& data, uint width, uint height,
                            bool  sixteenBit, bool hasAlpha,
-                           bool* cancel=0);
+                           bool* cancel = nullptr);
 
     /**
      * Tells to host application to render a preview image for one item.
-     * A resizement to to a specific size will be generated if preview is largest than.
+     * A resizement to a specific size will be generated if preview is largest than.
      * Use a positive resizedTo value in this case, else -1. Aspect ratio is preserved while rendering.
      * This asynchronous method must be re-implemented in host application.
      * Use gotPreview() signal to take preview.
@@ -413,7 +413,7 @@ public:
      * Returns if the item is reserved. You can pass a pointer to a QString; if the return value
      * is true, the string will be set to the descriptionOfAction set with reserveForAction.
      */
-    virtual bool itemIsReserved(const QUrl& url, QString* const descriptionOfAction = 0) const;
+    virtual bool itemIsReserved(const QUrl& url, QString* const descriptionOfAction = nullptr) const;
 
     /**
      * Supported if HostSupportsReadWriteLock
@@ -475,7 +475,7 @@ Q_SIGNALS:
      */
     void gotThumbnail(const QUrl&, const QPixmap&);
 
-    /** Emit when host application has rendered item preview image. See assynchronous preview() methods for details.
+    /** Emit when host application has rendered item preview image. See asynchronous preview() methods for details.
      */
     void gotPreview(const QUrl&, const QImage&);
 
